@@ -16,7 +16,7 @@ import requests, datetime
 import pandas as pd
 import numpy as np
 import json
-from com import *
+from common.com import *
 from pub_cls_com import *
 '''Date: 2021.03.15'''
 
@@ -114,7 +114,7 @@ def _handle_ex_ret(code_list=['00700'], queryType='profit', start_date='2018-12-
             "periodMark": period,
             "current": page
         }
-    
+
     df_ = total_handle_req(body=body, URL=EX_FIN_POST_URL)
 
     return df_
