@@ -16,7 +16,7 @@ import requests, datetime
 import pandas as pd
 import numpy as np
 import json
-from com import *
+from common.com import *
 from pub_cls_com import *
 '''Date: 2021.03.16'''
 
